@@ -38,6 +38,7 @@ import importlib
 import mimetypes
 import multiprocessing
 import re
+import time
 import urllib.parse as parse
 import warnings
 from functools import wraps
@@ -45,6 +46,7 @@ from http.server import BaseHTTPRequestHandler, HTTPServer
 from typing import Union
 
 import serverly.stater
+import serverly.statistics
 from fileloghelper import Logger
 from serverly import default_sites
 from serverly.objects import Request, Response
@@ -53,7 +55,7 @@ from serverly.utils import *
 description = "A really simple-to-use HTTP-server"
 address = ("localhost", 8080)
 name = "serverly"
-version = "0.3.1"
+version = "0.4.0"
 logger = Logger("serverly.log", "serverly", False, False)
 logger.header(True, True, description, fileloghelper_version=True,
               program_version="serverly v" + version)
@@ -69,68 +71,36 @@ class Handler(BaseHTTPRequestHandler):
         self.end_headers()
         self.wfile.write(bytes(response.body, "utf-8"))
 
-    def do_GET(self):
+    def handle_request(self, method: str):
         try:
             parsed_url = parse.urlparse(self.path)
             data_length = int(self.headers.get("Content-Length", 0))
             received_data = str(self.rfile.read(data_length), "utf-8")
-            request = Request("GET", parsed_url, dict(
+            request = Request(method, parsed_url, dict(
                 self.headers), received_data, self.client_address)
+            t1 = time.perf_counter()
             response = _sitemap.get_content(request)
+            t2 = time.perf_counter()
             self.respond(response)
-            logger.context = name + ": GET"
+            logger.context = name + ": " + method
             logger.debug(str(response))
+            serverly.statistics.calculation_times.append(t2 - t1)
         except Exception as e:
             serverly.stater.error(logger)
             logger.handle_exception(e)
             raise e
 
+    def do_GET(self):
+        self.handle_request("GET")
+
     def do_POST(self):
-        try:
-            parsed_url = parse.urlparse(self.path)
-            data_length = int(self.headers.get("Content-Length", 0))
-            received_data = str(self.rfile.read(data_length), "utf-8")
-            request = Request("POST", parsed_url, dict(
-                self.headers), received_data, self.client_address)
-            response = _sitemap.get_content(request)
-            self.respond(response)
-            logger.context = name + ": POST"
-            logger.debug(str(response))
-        except Exception as e:
-            serverly.stater.error(logger)
-            logger.handle_exception(e)
+        self.handle_request("POST")
 
     def do_PUT(self):
-        try:
-            parsed_url = parse.urlparse(self.path)
-            data_length = int(self.headers.get("Content-Length", 0))
-            received_data = str(self.rfile.read(data_length), "utf-8")
-            request = Request("PUT", parsed_url, dict(
-                self.headers), received_data, self.client_address)
-            response = _sitemap.get_content(request)
-            self.respond(response)
-            logger.context = name + ": PUT"
-            logger.debug(str(response))
-        except Exception as e:
-            serverly.stater.error(logger)
-            logger.handle_exception(e)
-            raise e
+        self.handle_request("PUT")
 
     def do_DELETE(self):
-        try:
-            parsed_url = parse.urlparse(self.path)
-            data_length = int(self.headers.get("Content-Length", 0))
-            received_data = str(self.rfile.read(data_length), "utf-8")
-            request = Request("DELETE", parsed_url, dict(
-                self.headers), received_data, self.client_address)
-            response = _sitemap.get_content(request)
-            self.respond(response)
-            logger.context = name + ": DELETE"
-            logger.debug(str(response))
-        except Exception as e:
-            serverly.stater.error(logger)
-            logger.handle_exception(e)
-            raise e
+        self.handle_request("DELETE")
 
 
 class Server:
@@ -206,6 +176,7 @@ class Server:
             if callable(self.cleanup_function):
                 self.cleanup_function()
             logger.success("Server stopped.")
+            serverly.statistics.print_stats()
 
 
 _server: Server = None
@@ -311,7 +282,7 @@ class Sitemap:
         found = False
         for key in self.methods[method].keys():
             if path == key:
-                found = True  # deleting right here raises RuntimeError
+                found = True
         if found:
             del self.methods[method][key]
             logger.context = "registration"
@@ -329,6 +300,7 @@ class Sitemap:
             try:
                 content = site(request)
             except TypeError as e:  # makes debugging easier
+                serverly.logger.handle_exception(e)
                 try:
                     content = site()
                 except TypeError as e:
@@ -384,34 +356,6 @@ class Sitemap:
 _sitemap = Sitemap()
 
 
-def serves_get(path: str):
-    """Decorator for registering a function for `path`, with method GET"""
-    logger.handle_exception(DeprecationWarning(
-        "serverly.serves_get() and serves_post() are deprecated since serverly v0.3.0. Please use serverly.serves('GET') instead."))
-
-    def wrapper_function(func):
-        _sitemap.register_site("GET", func, path)
-        @wraps(func)
-        def wrapper(*args, **kwargs):
-            return func(*args, **kwargs)
-        return wrapper
-    return wrapper_function
-
-
-def serves_post(path: str):
-    """Decorator for registering a function for `path`, with method POST"""
-    logger.handle_exception(DeprecationWarning(
-        "serverly.serves_get() and serves_post() are deprecated since serverly v0.3.0. Please use serverly.serves('POST') instead."))
-
-    def wrapper_function(func):
-        _sitemap.register_site("POST", func, path)
-        @wraps(func)
-        def wrapper(*args, **kwargs):
-            return func(*args, **kwargs)
-        return wrapper
-    return wrapper_function
-
-
 def serves(method: str, path: str):
     """Decorator for registering a function for `path`, with `method`"""
     def wrapper_function(func):
